@@ -4,12 +4,14 @@ use atomic_lib::{errors::AtomicResult, Storelike};
 use clap::{crate_version, App, AppSettings, Arg, ArgMatches, SubCommand};
 use colored::*;
 use dirs::home_dir;
-use path::SERIALIZE_OPTIONS;
 use std::{cell::RefCell, path::PathBuf, sync::Mutex};
 
+use crate::print::{SERIALIZE_OPTIONS, print_resource};
+
 mod commit;
 mod new;
 mod path;
+mod print;
 
 #[allow(dead_code)]
 /// The Context contains all the data for executing a single CLI command, such as the passed arguments and the in memory store.
@@ -35,7 +37,7 @@ impl Context<'_> {
             subject: write_ctx.agent.clone(),
             private_key: Some(write_ctx.private_key.clone()),
             created_at: atomic_lib::datetime_helpers::now(),
-            name: format!("Temporary name for {}", write_ctx.agent),
+            name: None,
             public_key: generate_public_key(&write_ctx.private_key).public,
         });
         write_ctx
@@ -133,6 +135,13 @@ fn main() -> AtomicResult<()> {
                     .help("The value URL or bookmark to be filtered by. Use a dot '.' to indicate 'any'.")
                     .required(true)
                 )
+                .arg(Arg::with_name("as")
+                    .long("as")
+                    .possible_values(&SERIALIZE_OPTIONS)
+                    .default_value("pretty")
+                    .help(&"Serialization format")
+                    .takes_value(true)
+                )
         )
         .subcommand(
             SubCommand::with_name("set")
@@ -256,7 +265,7 @@ fn exec_command(context: &mut Context) -> AtomicResult<()> {
             tpf(context)?;
         }
         Some("validate") => {
-            validate(context)?;
+            validate(context);
         }
         Some(cmd) => return Err(format!("{} is not a valid command. Run atomic --help", cmd).into()),
         None => println!("Run atomic --help for available commands"),
@@ -277,32 +286,17 @@ fn list(context: &mut Context) {
     println!("{}", string)
 }
 
-/// Returns a resource for the terminal with readble formatting and colors
-fn pretty_print_resource(url: &str, store: &impl Storelike) -> AtomicResult<String> {
-    let mut output = String::new();
-    let resource = store.get_resource(url)?;
-    for (prop_url, val) in resource.get_propvals() {
-        let prop_shortname = store.get_property(&prop_url)?.shortname;
-        output.push_str(&*format!(
-            "{0: <15}{1: <10} \n",
-            prop_shortname.blue().bold(),
-            val.to_string()
-        ));
-    }
-    output.push_str(&*format!("{0: <15}{1: <10} \n", "subject".blue().bold(), url));
-    Ok(output)
-}
-
 /// Triple Pattern Fragment Query
-fn tpf(context: &mut Context) -> AtomicResult<()> {
+fn tpf(context: &Context) -> AtomicResult<()> {
     let subcommand_matches = context.matches.subcommand_matches("tpf").unwrap();
     let subject = tpf_value(subcommand_matches.value_of("subject").unwrap());
     let property = tpf_value(subcommand_matches.value_of("property").unwrap());
     let value = tpf_value(subcommand_matches.value_of("value").unwrap());
     let endpoint = format!("{}/tpf", &context.get_write_context().server);
-    let atoms = atomic_lib::client::fetch_tpf(&endpoint, subject, property, value)?;
-    let serialized = atomic_lib::serialize::serialize_atoms_to_ad3(atoms)?;
-    println!("{}", serialized);
+    let resources = atomic_lib::client::fetch_tpf(&endpoint, subject, property, value, &context.store)?;
+    for r in resources {
+        print_resource(context, &r, subcommand_matches)?;
+    }
     Ok(())
 }
 
@@ -316,10 +310,9 @@ fn tpf_value(string: &str) -> Option<&str> {
 }
 
 /// Validates the store
-fn validate(context: &mut Context) -> AtomicResult<()> {
+fn validate(context: &mut Context) {
     let reportstring = context.store.validate().to_string();
     println!("{}", reportstring);
-    Ok(())
 }
 
 #[cfg(test)]
